@@ -50,12 +50,18 @@ class Statbotics:
         return out
 
     def _get(self, url, fields, retry=0):
+        print(url)
         resp = self.session.get(self.BASE_URL + url)
+        print(resp.json())
         if resp.status_code != 200:
             if retry < 2:
                 return self._get(url, fields, retry=retry + 1)
             raise UserWarning("Invalid query: " + url)
-        data = resp.json()["results"]
+        data = resp.json()
+        try:
+            return data["results"]
+        except KeyError:
+            return data
 
         if len(data) == 0:
             raise UserWarning("Invalid inputs, no data recieved for " + url)
@@ -564,8 +570,10 @@ class Statbotics:
         if full:
             url += "/full"
             if iterations:
+                if iterations > 100:
+                    raise ValueError("Iterations must be <= 100")
                 url += "/iterations/" + str(iterations)
         else:
             url += "/simple"
 
-        return self._get(url)
+        return self._get(url, fields=["all"])
